/*
 *    Copyright 2009 The JUnice Team
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.junice.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.google.inject.name.Named;
import com.googlecode.junice.GuiceMockModule;

/**
 * Annotate your filed into which {@link GuiceMockModule} will create and inject 
 * the mock object.
 *
 * @author Marco Speranza
 * @version $Id: Mock.java 245 2010-07-10 19:52:45Z marco.speranza79 $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
@Inherited
public @interface Mock {

    public class NoAnnotation { }

    /**
     * Indicates if this mock object has to be resetted after each test method
     * Default: true 
     * @return the value
     */
    public boolean resetAfter() default true;

    /**
     * The name of the method that provides to mock creation.
     * 
     * @return
     */
    public String providedBy() default "";

    /**
     * The {@link Class} that contains the method {@link Mock#providedBy()}.
     * By default: the filed declaring class.
     *   
     * @return
     */
    public Class<?> providerClass() default Object.class;

    /**
     * Specifies an annotaion {@link Class} that will be used in the <em>Google Guice</em> binder
     * to execute the literal annotating binding.
     * 
     * @return
     */
    public Class<?> annotatedWith() default NoAnnotation.class;
    
    
    /**
     * Specifies an {@link String} annotation that will be used in the <em>Google Guice</em> binder
     * to execute the literal annotating binding via {@link Named} class.
     * 
     * @return
     */
    public String namedWith() default "";
    
    /**
     * Specifies 
     * 
     * @return
     */
    public MockObjType type() default MockObjType.DEFAULT;

}
